Module mdns

Module mdns 

mDNS (Multicast DNS) parser — RFC 6762.

mDNS shares the DNS wire format but uses the top bit of qclass for the unicast-response flag and the cache-flush flag in resource records.

Structs

MdnsPacket
mDNS packet wrapper. Internally delegates to DnsPacket since mDNS uses the identical DNS wire format (RFC 6762 18).

Functions

is_cache_flush
Check whether the cache-flush bit is set in a record class field (RFC 6762 10.2). Top bit of the 16-bit class means “flush cache.”